==> haskell-network-uri-2.6.1.0-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-network-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
key: network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
exposed-modules:
    Network.URI
abi: 747f48c97ef288bf79bcc1087ca0f30d
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-uri-2.6.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
depends:
    base-4.9.0.0 deepseq-1.4.2.0 parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-uri-2.6.1.0-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-network-uri.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-uri
version: 2.6.1.0
id: network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
key: network-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
license: BSD3
maintainer: ezra@ezrakilty.net
homepage: https://github.com/haskell/network-uri
synopsis: URI manipulation
description:
    This package provides an URI manipulation interface.
    .
    In network-2.6 the @Network.URI@ module was split off from the
    network package into this package. If you'\''re using the @Network.URI@
    module you can automatically get it from the right package by adding
    this to your .cabal file:
    .
    > flag network-uri
    >   description: Get Network.URI from the network-uri package
    >   default: True
    >
    > library
    >   -- ...
    >   if flag(network-uri)
    >     build-depends: network-uri >= 2.6, network >= 2.6
    >   else
    >     build-depends: network-uri < 2.6, network < 2.6
    .
    That is, get the module from either network < 2.6 or from
    network-uri >= 2.6.
category: Network
exposed: True
exposed-modules:
    Network.URI
abi: 030a431fc098e4af754c0a18e234a112
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/network-uri-2.6.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/network-uri-2.6.1.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/network-uri-2.6.1.0
hs-libraries: HSnetwork-uri-2.6.1.0-FJ8JXDcVJz8KYX76kkCObd
depends:
    base-4.9.0.0 deepseq-1.4.2.0 parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
haddock-interfaces: /usr/share/doc/haskell-network-uri/html/network-uri.haddock
haddock-html: /usr/share/doc/haskell-network-uri/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
